@@ -4,7 +4,7 @@
 #' applies the receptor-noise model of Vorobyev et al. (1998) to calculate
 #' colour distances with noise based on relative photoreceptor densities. It
 #' also accepts [colspace()] data in which case unweighted Euclidean distances,
-#' CIE2000 distances (cielab and cielch only), or Manhattan distances (coc model only) 
+#' CIE2000 distances (cielab and cielch only), or Manhattan distances (coc model only)
 #' are returned.
 #'
 #' @param modeldata (required) quantum catch colour data. Can be the result from
@@ -77,7 +77,7 @@
 #'   previously, which also offers greater flexibility and reliability. Thus
 #'   [coldist()] now returns unweighted Euclidean distances for `colspace`
 #'   objects (with the exception of Manhattan distances for the coc space, and CIE2000,
-#'   distances for CIELab and CIELCh spaces), and noise-weighted Euclidean distances 
+#'   distances for CIELab and CIELCh spaces), and noise-weighted Euclidean distances
 #'   for `vismodel` objects.
 #'
 #' @export
@@ -89,7 +89,7 @@
 #' @examples
 #' \donttest{
 #' # Dichromat
-#' data(flowers)  
+#' data(flowers)
 #' vis.flowers <- vismodel(flowers, visual = "canis", relative = FALSE)
 #' didist.flowers <- coldist(vis.flowers, n = c(1, 2))
 #'
@@ -144,36 +144,36 @@ coldist <- function(modeldata,
                     achromatic = FALSE, qcatch = NULL,
                     n = c(1, 2, 2, 4), weber = 0.1, weber.ref = "longest",
                     weber.achro = 0.1) {
-  
+
   # Prepare output
   pairsid <- t(combn(nrow(modeldata), 2))
-  
+
   # Prepare pairwise combinations of stimuli for output
   res <- as.data.frame(matrix(rownames(modeldata)[pairsid],
                               ncol = 2, dimnames = list(NULL, c("patch1", "patch2"))
   ), stringsAsFactors = FALSE)
-  
+
   res[, "dS"] <- NA # Chromatic contrasts
   if (achromatic) { # Achromatic contrasts
     res[, "dL"] <- NA
   }
-  
+
   noise <- match.arg(noise)
-  
+
   usereceptornoisemodel <- !inherits(modeldata, "colspace")
-  
+
   if (noise == "quantum") {
     if (!is.vismodel(modeldata) && !is.colspace(modeldata)) {
       stop("Object must be of class vismodel or colspace to calculate quantum receptor noise model", call. = FALSE)
     }
   }
-  
+
   ncone <- attr(modeldata, "conenumb")
-  
+
   if (isTRUE(attr(modeldata, "relative"))) {
     message("Quantum catch are relative, distances may not be meaningful")
   }
-  
+
   # Pre-processing for colspace objects
   if (is.colspace(modeldata) || is.vismodel(modeldata)) {
     qcatch <- attr(modeldata, "qcatch")
@@ -196,7 +196,7 @@ coldist <- function(modeldata,
       achromatic <- FALSE
     }
   }
-  
+
   # Transformations in case object is neither from colspace or vismodel. Changed
   # warnings to messages, since there's no way to directly specify 'ncone' when using
   # custom data you'd always get scary warnings.
@@ -207,8 +207,7 @@ coldist <- function(modeldata,
         "Number of cones assumed to be ", ncone,
         " (last column ignored for chromatic contrast, used only for achromatic contrast)"
       )
-    }
-    else {
+    } else {
       # Don't count all-NA columns when guessing ncone
       # FIXME: this only works if there is a single all-NA column. But we have
       # no guarantee this will always be the case
@@ -220,31 +219,31 @@ coldist <- function(modeldata,
       message("Number of cones assumed to be ", ncone)
     }
   }
-  
+
   if (is.null(qcatch)) {
     stop("Scale of quantum catches not defined (Qi or fi in argument qcatch).",
          call. = FALSE
     )
   }
-  
+
   if (usereceptornoisemodel) {
-    
+
     #########################
     # Receptor Noise Models #
     #########################
-    
+
     # should be used when:
     # - colspace object: never
     # - vismodel object: always
     # - user input data: always
-    
+
     note_dS <- "Calculating noise-weighted Euclidean distances"
     note_dL <- NULL
-    
+
     dat <- as.matrix(modeldata)
     rownames(dat) <- rownames(modeldata)
     colnames(dat) <- colnames(modeldata)
-    
+
     # Ensure catches are log transformed
     dat <- switch(qcatch,
                   fi = dat,
@@ -256,10 +255,10 @@ coldist <- function(modeldata,
                     Qi = dat,
                     fi = exp(dat)
     )
-    
+
     # Keep only cone-catch data
     dat2 <- dat[, seq_len(ncone), drop = FALSE]
-    
+
     if (is.numeric(weber.ref) && weber.ref > length(n)) {
       stop("reference cone class for the empirical estimate of the Weber fraction (",
            dQuote("weber ref"),
@@ -268,22 +267,22 @@ coldist <- function(modeldata,
            call. = FALSE
       )
     }
-    
+
     # Set weber cone reference
     if (weber.ref == "longest") {
       weber.ref <- length(n)
     }
-    
+
     if (length(n) != ncone) {
       stop("vector of relative cone densities (", dQuote("n"),
            ") has a different length than the number of cones (columns) used for the visual model",
            call. = FALSE
       )
     }
-    
+
     # CREATE REFERENCE OBJECTS FOR CARTESIAN TRANSFORMATION
     refsamp <- min(dim(dat2)[1], ncone)
-    
+
     visref <- matrix(NA,
                      ncol = ncone,
                      nrow = refsamp + ncone + 1,
@@ -295,17 +294,17 @@ coldist <- function(modeldata,
                        colnames(dat2)
                      )
     )
-    
+
     rrf <- diag(9, ncone)
     rrf[lower.tri(rrf)] <- 0.001
     rrf[upper.tri(rrf)] <- 0.001
-    
+
     rrf <- log(rrf)
-    
+
     visref[seq(refsamp), ] <- dat2[seq(refsamp), ]
     visref[refsamp + 1, ] <- log(1e-10)
     visref[-seq(refsamp + 1), ] <- rrf
-    
+
     resref <- as.data.frame(matrix(rownames(visref)[t(combn(nrow(visref), 2))],
                                    ncol = 2, dimnames = list(NULL, c("patch1", "patch2"))
     ), stringsAsFactors = FALSE)
@@ -313,7 +312,7 @@ coldist <- function(modeldata,
     if (achromatic) {
       resref[, "dL"] <- NA
     }
-    
+
     ## Calculate dS
     res[, "dS"] <- switch(noise,
                           "neural" = newreceptornoise(dat2, n, weber, weber.ref, res),
@@ -323,53 +322,57 @@ coldist <- function(modeldata,
                              "neural" = newreceptornoise(visref, n, weber, weber.ref, resref),
                              "quantum" = newreceptornoise(visref, n, weber, weber.ref, resref, exp(visref))
     )
-    
+
     ## Calculate dL
     if (achromatic) {
       note_dL <- " and noise-weighted luminance contrasts"
       visref <- cbind(visref, lum = log(1e-10))
-      visref[grep("jnd2xyzrrf", rownames(visref), invert = TRUE), "lum"] <-
+      visref[grep("jnd2xyzrrf", rownames(visref), invert = TRUE, fixed = TRUE), "lum"] <-
         dat[seq(refsamp), dim(dat)[2]]
-      
+
       res[, "dL"] <- switch(noise,
-                            "neural" = unlist(lapply(seq(nrow(res)), function(x) {
+                            "neural" = unlist(lapply(seq_len(nrow(res)), function(x) {
                               ttdistcalcachro(
                                 dat[res[x, 1], ], dat[res[x, 2], ],
                                 NULL, NULL, weber.achro
                               )
                             })),
-                            "quantum" = unlist(lapply(seq(nrow(res)), function(x) {
+                            "quantum" = unlist(lapply(seq_len(nrow(res)), function(x) {
                               ttdistcalcachro(
                                 dat[res[x, 1], ], dat[res[x, 2], ],
                                 qndat[res[x, 1], ], qndat[res[x, 2], ], weber.achro
                               )
                             }))
       )
-      
+
       resref[, "dL"] <- switch(noise,
-                               "neural" = unlist(lapply(seq(nrow(resref)), function(x) {
+                               "neural" = unlist(lapply(seq_len(nrow(resref)), function(x) {
                                  ttdistcalcachro(
                                    visref[resref[x, 1], ], visref[resref[x, 2], ],
                                    NULL, NULL,
                                    weber.achro = weber.achro
                                  )
                                })),
-                               "quantum" = unlist(lapply(seq(nrow(resref)), function(x) {
+                               "quantum" = unlist(lapply(seq_len(nrow(resref)), function(x) {
                                  ttdistcalcachro(
                                    visref[resref[x, 1], ], visref[resref[x, 2], ],
                                    exp(visref)[resref[x, 1], ], exp(visref)[resref[x, 2], ], weber.achro
                                  )
                                }))
       )
-      
+
       if (dim(dat)[2] <= ncone) {
-        warning("achromatic is set to TRUE, but input data has the same number of columns for sensory data as number of cones in the visual system. There is no column in the data that represents an exclusively achromatic channel, so the last column of the sensory data is being used. Treat achromatic results with caution, and check if this is the desired behavior.", call. = FALSE)
+        warning(
+          "achromatic is set to TRUE, but input data has the same number of columns for sensory data as number of cones in the visual system. ",
+          "There is no column in the data that represents an exclusively achromatic channel, so the last column of the sensory data is being used. ",
+          "Treat achromatic results with caution, and check if this is the desired behavior.", call. = FALSE
+        )
       }
     }
     message(note_dS, note_dL)
   } else {
     dat <- as.matrix(modeldata[, sapply(modeldata, is.numeric)])
-    
+
     # Message about the distances being calculated
     note_dS <- switch(attr(modeldata, "clrsp"),
                       "dispace" = ,
@@ -384,7 +387,7 @@ coldist <- function(modeldata,
                       "coc" = "Calculating Manhattan distances"
     )
     note_dL <- NULL
-    
+
     res[, "dS"] <- switch(attr(modeldata, "clrsp"),
                           "dispace" = apply(pairsid, 1, function(x) dist(rbind(dat[x[1], "x"], dat[x[2], "x"]))),
                           "tcs" = apply(pairsid, 1, function(x) dist(rbind(dat[x[1], c("x", "y", "z")], dat[x[2], c("x", "y", "z")]))),
@@ -394,7 +397,10 @@ coldist <- function(modeldata,
                           "categorical" = apply(pairsid, 1, function(x) dist(rbind(dat[x[1], c("x", "y")], dat[x[2], c("x", "y")]))),
                           "segment" = apply(pairsid, 1, function(x) dist(rbind(dat[x[1], c("MS", "LM")], dat[x[2], c("MS", "LM")]))),
                           "CIELAB" = ,
-                          "CIELCh" = apply(pairsid, 1, function(x) compare_colour(as.data.frame(dat)[x[1], c("L", "a", "b")], as.data.frame(dat)[x[2], c("L", "a", "b")], from_space = 'lab', method = 'cie2000')),
+                          "CIELCh" = apply(pairsid, 1, function(x) {
+                            d <- as.data.frame(dat)
+                            compare_colour(d[x[1], c("L", "a", "b")], d[x[2], c("L", "a", "b")], from_space = "lab", method = "cie2000")
+                          }),
                           "coc" = apply(pairsid, 1, function(x) dist(rbind(dat[x[1], c("x", "y")], dat[x[2], c("x", "y")]), method = "manhattan"))
     )
     if (achromatic) {
@@ -409,7 +415,7 @@ coldist <- function(modeldata,
                         "coc" = ,
                         "CIELCh" = " and Weber luminance contrast",
       )
-      
+
       res[, "dL"] <- switch(attr(modeldata, "clrsp"),
                             "dispace" = ,
                             "trispace" = ,
@@ -424,51 +430,51 @@ coldist <- function(modeldata,
     }
     message(note_dS, note_dL)
   }
-  
+
   # Subsetting samples
   if (length(subset) > 2) {
     stop("Too many subsetting conditions; one or two allowed.", call. = FALSE)
   }
-  
+
   if (length(subset) == 1) {
     condition1 <- grep(subset, res$patch1)
     condition2 <- grep(subset, res$patch2)
     subsamp <- unique(c(condition1, condition2))
     res <- res[subsamp, ]
   }
-  
+
   if (length(subset) == 2) {
     condition1 <- intersect(
       grep(subset[1], res$patch1),
       grep(subset[2], res$patch2)
     )
-    
+
     condition2 <- intersect(
       grep(subset[2], res$patch1),
       grep(subset[1], res$patch2)
     )
-    
+
     subsamp <- unique(c(condition1, condition2))
     res <- res[subsamp, ]
     row.names(res) <- NULL
   }
-  
+
   if (exists("resref", inherits = FALSE)) {
     attr(res, "resref") <- resref
   }
-  
+
   # Set achro contrasts to NA if no lum values supplied
   if (((is.vismodel(modeldata) || is.colspace(modeldata)) && attr(modeldata, "visualsystem.achromatic") == "none") || !(achromatic)) {
     res$dL <- NA
   }
-  
+
   # if (attr(modeldata, "visualsystem.achromatic") == "none" || !(achromatic)) {
   #   res$dL <- NA
   # }
-  
+
   attr(res, "ncone") <- ncone
   attr(res, "isrnoise") <- usereceptornoisemodel
-  
+
   res
 }
 
@@ -477,17 +483,17 @@ coldist <- function(modeldata,
 ##################################
 
 newreceptornoise <- function(qcatch_raw, n, weber, weber.ref, res, qcatch_log = NULL) {
-  
+
   # Calculate relative receptor density
   reln <- n / sum(n)
-  
+
   # Back-calculate photoreceptor noise from channel-noise (weber fraction)
   if (length(weber) == length(n)) { # For when weber is known for all receptors
     v <- weber * sqrt(reln)
   } else {
     v <- weber * sqrt(reln[weber.ref])
   } # When weber is known for one receptor (typical)
-  
+
   if (is.null(qcatch_log)) {
     e <- setNames(v / sqrt(reln), colnames(qcatch_raw))
   } else {
@@ -497,7 +503,7 @@ newreceptornoise <- function(qcatch_raw, n, weber, weber.ref, res, qcatch_log =
         length(qcatch_log[qcatch_log < 0]),
         " negative quantum-catch value(s) returned following log-transformation, as required when noise = 'quantum',
         so distances cannot be calculated. This typically results from very small raw quantum catches estimates (< 1).",
-        "Consider whether the illuminant is properly scaled, and/or the appropriate",
+        "Consider whether the illuminant is properly scaled, and the appropriate",
         " form of noise is being calculated."
       )
     }
@@ -505,14 +511,14 @@ newreceptornoise <- function(qcatch_raw, n, weber, weber.ref, res, qcatch_log =
     ept2 <- 2 / t(apply(res, 1, function(x) qcatch_log[x[1], ] + qcatch_log[x[2], ]))
     e <- sqrt(sweep(ept2, 2, ept1, "+"))
   }
-  
+
   ###############
   # NUMERATOR #
   ###############
-  
+
   # all n-2 combinations (first part numerator)
   n1combs <- combn(colnames(qcatch_raw), dim(qcatch_raw)[2] - 2)
-  
+
   if (is.null(qcatch_log)) {
     # get those combinations of ei and prod(ei)^2
     num1 <- setNames(
@@ -521,43 +527,43 @@ newreceptornoise <- function(qcatch_raw, n, weber, weber.ref, res, qcatch_log =
     )
   } else {
     # get those combinations of ei and prod(ei)^2
-    num1 <- do.call("rbind", lapply(1:dim(res)[1], function(z) {
+    num1 <- do.call("rbind", lapply(seq_len(dim(res)[1]), function(z) {
       apply(n1combs, 2, function(x) prod(e[z, x]))
     }))
     colnames(num1) <- apply(n1combs, 2, paste, collapse = "")
   }
-  
+
   # remaining 2 combinations (second part numerator)
   n2combs <- apply(n1combs, 2, function(x) colnames(qcatch_raw)[!colnames(qcatch_raw) %in% x])
-  
+
   # f_d and f_e
-  deltaqiqj <- lapply(1:dim(n1combs)[2], function(y) {
+  deltaqiqj <- lapply(seq_len(dim(n1combs)[2]), function(y) {
     t(apply(res, 1, function(x) {
       qcatch_raw[x[1], n2combs[, y]] - qcatch_raw[x[2], n2combs[, y]]
     }))
   })
   names(deltaqiqj) <- apply(n2combs, 2, paste, collapse = "")
-  
+
   # (f_d-f_e)^2
   num2 <- do.call(cbind, lapply(deltaqiqj, function(x) x[, 1] - x[, 2]))
-  
+
   # (e_abc)^2*(f_d-f_e)^2
   if (is.null(qcatch_log)) {
     etimesq <- num2 %*% diag(num1)
   } else {
     etimesq <- num2 * num1
   }
-  
+
   # sum numerator
   numerator <- rowSums(etimesq^2)
-  
+
   ###############
   # DENOMINATOR #
   ###############
-  
+
   # all n-1 combinations
   dcombs <- combn(colnames(qcatch_raw), dim(qcatch_raw)[2] - 1)
-  
+
   if (is.null(qcatch_log)) {
     den <- setNames(
       apply(dcombs, 2, function(x) prod(e[x])),
@@ -565,7 +571,7 @@ newreceptornoise <- function(qcatch_raw, n, weber, weber.ref, res, qcatch_log =
     )
     denominator <- sum(den^2)
   } else {
-    den <- do.call("rbind", lapply(1:dim(res)[1], function(z) {
+    den <- do.call("rbind", lapply(seq_len(dim(res)[1]), function(z) {
       apply(dcombs, 2, function(x) prod(e[z, x]))
     }))
     colnames(den) <- apply(dcombs, 2, paste, collapse = "")
@@ -598,7 +604,7 @@ ttdistcalcachro <- function(f1, f2, qn1 = NULL, qn2 = NULL, weber.achro) {
 # Luminance contrast
 lumcont <- function(coord1, coord2, type = c("simple", "weber", "michelson")) {
   contrast <- match.arg(type)
-  
+
   dLout <- switch(contrast,
                   "simple" = coord1 / coord2,
                   "weber" = (pmax(coord1, coord2) - pmin(coord1, coord2)) / pmin(coord1, coord2),
