@@ -68,7 +68,9 @@ procspec <- function(rspecdata, opt = c(
   applied <- "processing options applied:"
 
   if (any(opt == "none")) {
-    opt <- "none" # remove other opt arguments (so they are not called further on, but still allowing for fixneg to work)
+    # remove other opt arguments (so they are not called further on, but still
+    # allowing for fixneg to work)
+    opt <- "none"
 
     if (fixneg == "none") {
       stop("No processing options selected")
@@ -135,7 +137,7 @@ procspec <- function(rspecdata, opt = c(
   if (any(opt == "bin")) {
     bw <- floor(length(wl) / (bins - 1))
     wl_bin <- wl_bin <- seq(min(wl), by = bw, length.out = bins)
-    rspecdata <- by(rspecdata, findInterval(wl, wl_bin), function(x) apply(x, 2, median))
+    rspecdata <- by(rspecdata, findInterval(wl, wl_bin), function(x) apply(x, 2, median)) # nolint
     rspecdata <- do.call(rbind, rspecdata)
     rspecdata <- cbind(wl_bin, rspecdata)
     applied <- c(applied, paste0("binned spectra to ", bw, "-nm intervals"))
