@@ -25,21 +25,17 @@
 segplot <- function(segdata, labels = TRUE, lab.cex = 0.9,
                     out.lwd = 1, out.lty = 1, out.lcol = "black",
                     tick.loc = c(-1, -0.5, 0.5, 1),
-                    square = TRUE, margins = NULL, ...) {
-  if (!missing("margins")) {
-    message("The 'margins' argument is deprecated, and will be ignored. See ?par() for guidance on 
-            setting margins in the standard manner.")
-  }
+                    square = TRUE, ...) {
 
   # Check if object is of class colorspace and tetrachromat
-  if (!is.colspace(segdata) & !all(c("LM", "MS") %in% names(segdata))) {
+  if (!is.colspace(segdata) && !all(c("LM", "MS") %in% names(segdata))) {
     stop(
       "object is not of class ", dQuote("colspace"),
       ", and does not contain LM, MS segment data"
     )
   }
 
-  if (is.colspace(segdata) & attr(segdata, "clrsp") != "segment") {
+  if (is.colspace(segdata) && attr(segdata, "clrsp") != "segment") {
     stop(dQuote("colspace"), " object is not a result of segspace()")
   }
 
