@@ -27,7 +27,6 @@
 #' @param out.lwd,out.lcol graphical parameters for the tetrahedral outline.
 #' @param type accepts a vector of length 1 or 2 with 'p' for points and/or 'l'
 #'   for lines from the point to the base of the tetrahedron.
-#' @param margin Deprecated. Please use the standard [par()] method for custom margins.
 
 #' @inheritParams triplot
 #'
@@ -64,11 +63,7 @@ tetraplot <- function(tcsdata, theta = 45, phi = 10, perspective = FALSE,
                       range = c(1, 2), r = 1e6, zoom = 1,
                       achro = TRUE, achro.col = "grey", achro.size = 1, achro.line = FALSE, achro.lwd = 1, achro.lty = 3,
                       tetrahedron = TRUE, vert.cex = 1, vert.range = c(1, 2), out.lwd = 1, out.lcol = "darkgrey",
-                      type = "p", labels = FALSE, gamut = FALSE, margin = NULL, ...) {
-  if (!missing("margin")) {
-    message("The 'margin' argument is deprecated, and will be ignored. See ?par() for guidance on
-            setting margins in the standard manner.")
-  }
+                      type = "p", labels = FALSE, gamut = FALSE, ...) {
 
   trange <- function(x, newmin, newmax) {
     (((x - min(x)) * (newmax - newmin)) / (max(x) - min(x))) + newmin
@@ -257,7 +252,7 @@ tetraplot <- function(tcsdata, theta = 45, phi = 10, perspective = FALSE,
     )
 
     # get 3 most in back
-    inback <- names(sort(combdist, )[seq_len(3)])
+    inback <- names(sort(combdist)[seq_len(3)])
 
     linback <- grepl(paste0(inback, collapse = "|"), rownames(segs))
 
