@@ -1,12 +1,12 @@
 test_that("as.rimg", {
   attributesuite <- function(x) {
-    expect_equal(class(x), c("rimg", "array"))
-    expect_equal(attr(x, "state"), "raw")
-    expect_equal(attr(x, "imgname"), "image")
-    expect_equal(attr(x, "px_scale"), NA)
-    expect_equal(attr(x, "raw_scale"), NA)
-    expect_equal(attr(x, "k"), NA)
-    expect_equal(attr(x, "outline"), NA)
+    expect_s3_class(x, c("rimg", "array"))
+    expect_identical(attr(x, "state"), "raw")
+    expect_identical(attr(x, "imgname"), "image")
+    expect_identical(attr(x, "px_scale"), NA)
+    expect_identical(attr(x, "raw_scale"), NA)
+    expect_identical(attr(x, "k"), NA)
+    expect_identical(attr(x, "outline"), NA)
   }
 
   # Fake image(s)
@@ -31,10 +31,10 @@ test_that("as.rimg", {
   expect_message(as.rimg(imgfake2), "[0,1]")
 
   # Classes/attributes/structure
-  expect_equal(dim(rimgfake), c(10, 10, 3))
-  expect_equal(dim(rimggrey), c(10, 10, 3))
-  expect_equal(dim(rimgfake2[[1]]), c(10, 10, 3))
-  expect_equal(dim(rimgfake2[[2]]), c(10, 10, 3))
+  expect_identical(dim(rimgfake), c(10L, 10L, 3L))
+  expect_identical(dim(rimggrey), c(10L, 10L, 3L))
+  expect_identical(dim(rimgfake2[[1]]), c(10L, 10L, 3L))
+  expect_identical(dim(rimgfake2[[2]]), c(10L, 10L, 3L))
   attributesuite(rimgfake)
   attributesuite(rimggrey)
   attributesuite(rimgfake2[[1]])
@@ -45,7 +45,7 @@ test_that("as.rimg", {
   expect_true(is.rimg(rimggrey))
 
   # as.rimg can handle user-classified images
-  papilio <- getimg(system.file("testdata/images/butterflies/papilio.png", package = "pavo"))
+  papilio <- getimg(system.file("testdata", "images", "butterflies", "papilio.png", package = "pavo"))
   papilio_class <- classify(papilio, kcols = 4)
   pap2 <- as.rimg(matrix(papilio_class, nrow = (nrow(papilio_class)), ncol = ncol(papilio_class)))
   expect_true(is.rimg(pap2))
@@ -53,17 +53,17 @@ test_that("as.rimg", {
 
   # magick conversion
   magickpapilio <- rimg2magick(papilio)
-  expect_equal(class(magickpapilio), "magick-image")
+  expect_s3_class(magickpapilio, "magick-image")
   papiliomagick <- as.rimg(magickpapilio)
   attr(papiliomagick, "imgname") <- "papilio"
   expect_equal(papilio, papiliomagick, ignore_attr = TRUE)
 })
 
 test_that("procimg", {
-  papilio <- getimg(system.file("testdata/images/butterflies/papilio.png", package = "pavo"))
+  papilio <- getimg(system.file("testdata", "images", "butterflies", "papilio.png", package = "pavo"))
 
   # Resize
-  expect_equal(dim(procimg(papilio, resize = 50))[1:2], dim(papilio)[1:2] / 2)
+  expect_identical(dim(procimg(papilio, resize = 50))[1:2], dim(papilio)[1:2] %/% 2L)
 
   # Messages/Errors
   expect_message(procimg(classify(papilio, kcols = 3), resize = 200), "Cannot resize")
@@ -79,7 +79,7 @@ test_that("procimg", {
   expect_warning(procimg(papilio, obj_width = 3), "Skipping")
   expect_warning(procimg(papilio, eye_res = 3), "Skipping")
   expect_warning(procimg(papilio, obj_width = 3, obj_dist = 3), "Skipping")
-  expect_warning(procimg(papilio, obj_width = 'black', obj_dist = 3, eye_res = 10), "Skipping")
+  expect_warning(procimg(papilio, obj_width = "black", obj_dist = 3, eye_res = 10), "Skipping")
   expect_warning(procimg(classify(papilio, kcols = 3), obj_width = 3, obj_dist = 3, eye_res = 10), "Skipping")
 })
 
@@ -102,7 +102,7 @@ test_that("classify", {
   expect_error(classify(imgfake), "kcols")
 
   fake_class <- classify(imgfake, kcols = 2)
-  expect_equal(dim(fake_class), c(8, 12))
+  expect_identical(dim(fake_class), c(8L, 12L))
   expect_true(is.rimg(fake_class))
 
   # Shouldn't fail even when user unnecessarily specifies refID for single img
@@ -120,7 +120,8 @@ test_that("classify", {
   ## Multiple
   fake_IDs <- data.frame(
     ID = c("fake_02.png", "fake_01.jpg"),
-    k = c(2, 2)
+    k = c(2, 2),
+    stringsAsFactors = FALSE
   )
 
   expect_error(classify(list(1, 1), kcols = fake_IDs), "array")
@@ -129,15 +130,15 @@ test_that("classify", {
   expect_true(is.rimg(fake2_class))
   expect_true(is.rimg(fake2_class[[1]]))
   expect_true(is.rimg(fake2_class[[2]]))
-  expect_equal(dim(fake2_class[[1]]), c(8, 12))
-  expect_equal(dim(fake2_class[[2]]), c(8, 12))
+  expect_identical(dim(fake2_class[[1]]), c(8L, 12L))
+  expect_identical(dim(fake2_class[[2]]), c(8L, 12L))
 
   fake2_class2 <- classify(imgfakes, kcols = fake_IDs, refID = 1)
   expect_true(is.rimg(fake2_class2))
   expect_true(is.rimg(fake2_class2[[1]]))
   expect_true(is.rimg(fake2_class2[[2]]))
-  expect_equal(dim(fake2_class2[[1]]), c(8, 12))
-  expect_equal(dim(fake2_class2[[2]]), c(8, 12))
+  expect_identical(dim(fake2_class2[[1]]), c(8L, 12L))
+  expect_identical(dim(fake2_class2[[2]]), c(8L, 12L))
 
   # k medoids
   expect_error(classify(imgfakes, method = "kMedoids", kcols = fake_IDs, refID = 1), "k-medoids")
@@ -146,8 +147,8 @@ test_that("classify", {
   expect_true(is.rimg(fake2_class3))
   expect_true(is.rimg(fake2_class3[[1]]))
   expect_true(is.rimg(fake2_class3[[2]]))
-  expect_equal(dim(fake2_class3[[1]]), c(8, 12))
-  expect_equal(dim(fake2_class3[[2]]), c(8, 12))
+  expect_identical(dim(fake2_class3[[1]]), c(8L, 12L))
+  expect_identical(dim(fake2_class3[[2]]), c(8L, 12L))
 
 
   # Messages
@@ -187,7 +188,8 @@ test_that("adjacency", {
     c1 = "wrong",
     c2 = 2,
     dS = 10,
-    dL = 1
+    dL = 1,
+    stringsAsFactors = FALSE
   )
   hsl_vals <- data.frame(
     patch = 1:2,
@@ -207,15 +209,15 @@ test_that("adjacency", {
   fake_adjacent_90 <- adjacent(fake_class_90, xpts = 8, xscale = 10, coldists = distances, hsl = hsl_vals, bkgID = 1)
   expect_message(adjacent(fake_class, xpts = 123, xscale = 10), "grid-sampling density")
   expect_gt(fake_adjacent$m_r, fake_adjacent_90$m_c)
-  expect_equal(fake_adjacent[, ncol(fake_adjacent):(ncol(fake_adjacent) - 8)], fake_adjacent_90[, ncol(fake_adjacent):(ncol(fake_adjacent) - 8)])
-  expect_equal(fake_adjacent$k, 2)
-  expect_equal(fake_adjacent$m_dS, 10)
-  expect_equal(fake_adjacent$m_dL, 1)
-  expect_equal(fake_adjacent$cv_sat, fake_adjacent$s_sat / fake_adjacent$m_sat)
-  expect_equal(fake_adjacent$cv_lum, fake_adjacent$s_lum / fake_adjacent$m_lum)
-  expect_equal(round(fake_adjacent$p_1, 1), round(fake_adjacent$p_2, 1))
+  expect_identical(fake_adjacent[, ncol(fake_adjacent):(ncol(fake_adjacent) - 8)], fake_adjacent_90[, ncol(fake_adjacent):(ncol(fake_adjacent) - 8)])
+  expect_identical(fake_adjacent$k, 2L)
+  expect_identical(fake_adjacent$m_dS, 10)
+  expect_identical(fake_adjacent$m_dL, 1)
+  expect_identical(fake_adjacent$cv_sat, fake_adjacent$s_sat / fake_adjacent$m_sat)
+  expect_identical(fake_adjacent$cv_lum, fake_adjacent$s_lum / fake_adjacent$m_lum)
+  expect_identical(round(fake_adjacent$p_1, 1), round(fake_adjacent$p_2, 1))
   expect_gt(fake_adjacent$N, fake_adjacent$n_off)
-  expect_equal(fake_adjacent$m, ((fake_adjacent$m_r + fake_adjacent$m_c) / 2))
+  expect_identical(fake_adjacent$m, ((fake_adjacent$m_r + fake_adjacent$m_c) / 2))
 
   # Multiple
   fake2_class <- classify(imgfakes, kcols = 2)
@@ -223,20 +225,20 @@ test_that("adjacency", {
 
   fake2_adjacent <- adjacent(fake2_class, xpts = 10, xscale = 150)
   expect_message(adjacent(fake2_class, xpts = 123, xscale = 10), "grid-sampling density")
-  expect_equal(fake2_adjacent$k, c(2, 2))
-  expect_equal(round(fake2_adjacent$p_1, 1), round(fake2_adjacent$p_2, 1))
+  expect_identical(fake2_adjacent$k, c(2L, 2L))
+  expect_identical(fake2_adjacent$p_1, fake2_adjacent$p_2)
   expect_gt(fake2_adjacent$N[1], fake2_adjacent$n_off[1])
-  expect_equal(fake2_adjacent$m, ((fake2_adjacent$m_r + fake2_adjacent$m_c) / 2))
+  expect_identical(fake2_adjacent$m, ((fake2_adjacent$m_r + fake2_adjacent$m_c) / 2))
 
   ## Single colour
   fake3_class <- classify(img1col, kcols = 1)
   fake3_adjacent <- adjacent(fake3_class, xpts = 100, xscale = 10)
-  expect_equal(fake3_adjacent$k, 1)
-  expect_equal(fake3_adjacent$p_1, 1)
-  expect_equal(fake3_adjacent$q_1_1, 1)
-  expect_equal(fake3_adjacent$q_1_1, 1)
-  expect_equal(fake3_adjacent$m, 0)
-  expect_equal(fake3_adjacent$Sc, 1)
+  expect_identical(fake3_adjacent$k, 1L)
+  expect_identical(fake3_adjacent$p_1, 1)
+  expect_identical(fake3_adjacent$q_1_1, 1)
+  expect_identical(fake3_adjacent$q_1_1, 1)
+  expect_identical(fake3_adjacent$m, 0)
+  expect_identical(fake3_adjacent$Sc, 1)
 
   ## Checkerboard (known values)
   distances <- data.frame(
@@ -253,29 +255,29 @@ test_that("adjacency", {
     sat = c(1, 6)
   )
   set.seed(1)
-  checker <- getimg(system.file("testdata/images/validation/checkerboard.png", package = "pavo"))
+  checker <- getimg(system.file("testdata", "images", "validation", "checkerboard.png", package = "pavo"))
   checker_class <- classify(checker, kcols = 2)
   checker_adj <- adjacent(checker_class, xscale = 10, xpts = 220, coldists = distances, hsl = hsl_vals)
-  expect_equal(checker_adj$k, 2)
-  expect_equal(checker_adj$N, (219 * 220) * 2)
-  expect_equal(checker_adj$p_2, 0.52)
-  expect_equal(checker_adj$p_1, 0.48)
-  expect_equal(checker_adj$t_1_2, 1)
-  expect_equal(checker_adj$m, 0.4)
-  expect_equal(checker_adj$m_r, 0.4)
-  expect_equal(checker_adj$m_c, 0.4)
-  expect_equal(checker_adj$A, 1)
-  expect_equal(checker_adj$St, 1)
-  expect_equal(checker_adj$Jt, 1)
-  expect_equal(checker_adj$m_dS, 10)
-  expect_equal(checker_adj$A, (checker_adj$m_r / checker_adj$m_c))
-  expect_equal(checker_adj$m_dL, 20)
-  expect_equal(checker_adj$m_hue, 1.5)
-  expect_equal(checker_adj$m_sat, 3.6)
-  expect_equal(checker_adj$m_lum, 5.68)
+  expect_identical(checker_adj$k, 2L)
+  expect_identical(checker_adj$N, (219L * 220L) * 2L)
+  expect_identical(checker_adj$p_2, 0.52)
+  expect_identical(checker_adj$p_1, 0.48)
+  expect_identical(checker_adj$t_1_2, 1)
+  expect_identical(checker_adj$m, 0.4)
+  expect_identical(checker_adj$m_r, 0.4)
+  expect_identical(checker_adj$m_c, 0.4)
+  expect_identical(checker_adj$A, 1)
+  expect_identical(checker_adj$St, 1)
+  expect_identical(checker_adj$Jt, 1)
+  expect_identical(checker_adj$m_dS, 10)
+  expect_identical(checker_adj$A, (checker_adj$m_r / checker_adj$m_c))
+  expect_identical(checker_adj$m_dL, 20)
+  expect_identical(checker_adj$m_hue, 1.5)
+  expect_identical(checker_adj$m_sat, 3.6)
+  expect_identical(checker_adj$m_lum, 5.68)
 
   # Can handle user-classified images
-  papilio <- getimg(system.file("testdata/images/butterflies/papilio.png", package = "pavo"))
+  papilio <- getimg(system.file("testdata", "images", "butterflies", "papilio.png", package = "pavo"))
   papilio_class <- classify(papilio, kcols = 4)
   papilio_adj <- adjacent(papilio_class, xscale = 100)
 
